is_plugged

Function is_plugged 

pub fn is_plugged(has_asked: bool) -> bool
Returns true if the laptop is plugged in Returns false if the laptop is not plugged in If on a device without battery, it will ask the user if they want to continue and return false if the user confirms